/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.dita.id;

import java.util.StringTokenizer;

import ro.sync.annotations.api.API;
import ro.sync.annotations.api.APIType;
import ro.sync.annotations.api.SourceType;
import ro.sync.ecss.extensions.api.node.AttrValue;
import ro.sync.ecss.extensions.api.node.AuthorElement;
import ro.sync.ecss.extensions.commons.id.DefaultUniqueAttributesRecognizer;
import ro.sync.ecss.extensions.commons.id.GenerateIDElementsInfo;

/**
 * Unique attributes recognizer for DITA.
 */
@API(type=APIType.INTERNAL, src=SourceType.PUBLIC)
public class DITAUniqueAttributesRecognizer extends DefaultUniqueAttributesRecognizer {
  
  /**
   * List of elements for which to generate IDs, comma separated
   */
  public static GenerateIDElementsInfo GENERATE_ID_DEFAULTS = new GenerateIDElementsInfo(true, GenerateIDElementsInfo.DEFAULT_ID_GENERATION_PATTERN, new String[] {
      "topic/topic", "topic/table", "topic/simpletable", "topic/image", "topic/ul", "topic/ol"});
  
  /**
   * Constructor
   */
  public DITAUniqueAttributesRecognizer() {
    super("id");
  }
  
  /**
   * @see ro.sync.ecss.extensions.commons.id.DefaultUniqueAttributesRecognizer#copyAttributeOnSplit(java.lang.String, ro.sync.ecss.extensions.api.node.AuthorElement)
   */
  @Override
  public boolean copyAttributeOnSplit(String attrQName, AuthorElement element) {
    return super.copyAttributeOnSplit(attrQName, element) && ! "conref".equals(attrQName);
  }

  /**
   * @see ro.sync.ecss.extensions.api.Extension#getDescription()
   */
  public String getDescription() {
    return "DITA Unique attributes recognizer";
  }
  
  /**
   * @see ro.sync.ecss.extensions.commons.id.DefaultUniqueAttributesRecognizer#getDefaultOptions()
   */
  @Override
  protected GenerateIDElementsInfo getDefaultOptions() {
    return GENERATE_ID_DEFAULTS;
  }
  
  /**
   * @see ro.sync.ecss.extensions.commons.id.DefaultUniqueAttributesRecognizer#getGenerateIDAttributeQName(ro.sync.ecss.extensions.api.node.AuthorElement, java.lang.String[], boolean)
   */
  @Override
  protected String getGenerateIDAttributeQName(AuthorElement element, String[] elemsWithAutoGeneration, boolean forceGeneration) {
    String idAttrName = super.getGenerateIDAttributeQName(element, elemsWithAutoGeneration, forceGeneration);
    if(idAttrName == null) {
      //Maybe class value match
      loop: for (int i = 0; i < elemsWithAutoGeneration.length; i++) {
        String pattern = elemsWithAutoGeneration[i];
        if (pattern.contains("/")) {
          //Class value, trim whitespace
          pattern = pattern.trim();
          //Class value match
          AttrValue clazz = element.getAttribute("class");
          if(clazz != null && clazz.getValue() != null) {
            String classValue =  clazz.getValue();
            StringTokenizer st = new StringTokenizer(classValue, " ", false);
            while(st.hasMoreTokens()) {
              String nextToken = st.nextToken();
              if(nextToken.equals(pattern)) {
                //Fill in the ID attribute.
                idAttrName = idAttrQname;
                break loop;
              }
            }
          }
        }
      }
    }
    return idAttrName;
  }
}
