/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2009 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.dita.map.table;

import ro.sync.annotations.api.API;
import ro.sync.annotations.api.APIType;
import ro.sync.annotations.api.SourceType;
import ro.sync.ecss.extensions.api.ArgumentDescriptor;
import ro.sync.ecss.extensions.api.ArgumentsMap;
import ro.sync.ecss.extensions.api.AuthorAccess;
import ro.sync.ecss.extensions.api.AuthorOperation;
import ro.sync.ecss.extensions.api.AuthorOperationException;
import ro.sync.ecss.extensions.commons.table.operations.TableInfo;

/**
 * Operation used to insert a DITA map reltable.
 */
@API(type=APIType.INTERNAL, src=SourceType.PUBLIC)
public class InsertTableOperation implements AuthorOperation {
  
  /**
   * @see ro.sync.ecss.extensions.api.AuthorOperation#doOperation(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.ArgumentsMap)
   */
  public void doOperation(AuthorAccess authorAccess, ArgumentsMap args)
      throws IllegalArgumentException, AuthorOperationException {
    // Show the 'Insert table' dialog
    TableInfo tableInfo = null;
    if(authorAccess.getWorkspaceAccess().isStandalone()) {
      tableInfo = new SADITARelTableCustomizer().customizeTable(authorAccess);
    } else {
      //Eclipse table customization
      tableInfo = new ECDITARelTableCustomizer().customizeTable(authorAccess);
    }

    if (tableInfo != null) {
      // Create the table XML fragment
      StringBuffer tableXMLFragment = new StringBuffer();
      if(tableInfo.getTitle() == null || tableInfo.getTitle().trim().length() == 0) {
        tableXMLFragment.append("<reltable>");
      } else {        
        tableXMLFragment.append("<reltable title=\"" + tableInfo.getTitle() + "\">");
      }

      // Add table header
      addRelTableHeader(tableXMLFragment, tableInfo);

      // Add table body
      addRelTableBody(tableXMLFragment, tableInfo);

      tableXMLFragment.append("</reltable>");


      // Insert the table 
      authorAccess.getDocumentController().insertXMLFragmentSchemaAware(
          tableXMLFragment.toString(), 
          authorAccess.getEditorAccess().getCaretOffset());
    } else {
      // User canceled the operation 
    }
  }

  /**
   * Add simple table body.
   */
  private void addRelTableBody(StringBuffer tableXMLFragment, TableInfo tableInfo) {
    for (int i = 0; i < tableInfo.getRowsNumber(); i++) {
      tableXMLFragment.append("<relrow>");
      for (int j = 0; j < tableInfo.getColumnsNumber(); j++) {
        tableXMLFragment.append("<relcell></relcell>"); 
      }
      tableXMLFragment.append("</relrow>"); 
    }
  }
  
  /**
   * Add simple table header.
   */
  private void addRelTableHeader(StringBuffer tableXMLFragment, TableInfo tableInfo) {
    if (tableInfo.isGenerateHeader()) {
      tableXMLFragment.append("<relheader>");
      for (int i = 1; i <= tableInfo.getColumnsNumber(); i++) {
        tableXMLFragment.append("<relcolspec type=\"topic\"/>");
      }
      tableXMLFragment.append("</relheader>");
    }
  }

  /**
   * No arguments. The operation will display a dialog for choosing the table attributes.
   * 
   * @see ro.sync.ecss.extensions.api.AuthorOperation#getArguments()
   */
  public ArgumentDescriptor[] getArguments() {
    return null;
  }

  /**
   * @see ro.sync.ecss.extensions.api.Extension#getDescription()
   */
  public String getDescription() {
    return "Insert a DITA map relationship table";
  }
}