/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2009 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.dita.topic.table.simpletable;

import ro.sync.annotations.api.API;
import ro.sync.annotations.api.APIType;
import ro.sync.annotations.api.SourceType;
import ro.sync.ecss.extensions.api.AuthorAccess;
import ro.sync.ecss.extensions.api.AuthorOperationException;
import ro.sync.ecss.extensions.api.AuthorTableCellSpanProvider;
import ro.sync.ecss.extensions.api.node.AuthorElement;
import ro.sync.ecss.extensions.commons.AbstractDocumentTypeHelper;

/**
 * Implementation of the document type helper for DITA simple table model
 */
@API(type=APIType.INTERNAL, src=SourceType.PUBLIC)
public class DITASimpleTableDocumentTypeHelper extends AbstractDocumentTypeHelper implements SimpleTableConstants {

  /**
   * The name of the elements representing a row in the table.
   */
  private static final String[] ROW_ELEMENT_NAMES =  new String[] {
    // simpletable
    ELEMENT_NAME_ROW_SIMPLETABLE, ELEMENT_NAME_HEADER_SIMPLETABLE,
    // choicetable
    ELEMENT_NAME_ROW_CHOICETABLE, ELEMENT_NAME_HEADER_CHOICETABLE,
    // properties
    ELEMENT_NAME_ROW_PROPERTIES, ELEMENT_NAME_HEADER_PROPERTIES};
  
  /**
   * The name of the elements representing a column in the table.
   */
  private static final String[] CELL_ELEMENT_NAMES = new String[] {
    // simpletable
    ELEMENT_NAME_ENTRY_SIMPLETABLE,
    // choicetable
    ELEMENT_NAME_CHDESCHD_CHOICETABLE, ELEMENT_NAME_CHOPTIONHD_CHOICETABLE, ELEMENT_NAME_CHDESC_CHOICETABLE, ELEMENT_NAME_CHOPTION_CHOICETABLE,
    // properties
    ELEMENT_NAME_PROPDESCHD_PROPERTIES, ELEMENT_NAME_PROPTYPEHD_PROPERTIES, ELEMENT_NAME_PROPVALUEHD_PROPERTIES, 
    ELEMENT_NAME_PROPDESC_PROPERTIES, ELEMENT_NAME_PROPTYPE_PROPERTIES, ELEMENT_NAME_PROPVALUE_PROPERTIES,};
  
  /**
   * The name of the elements representing a table.
   */
  private static final String[] TABLE_ELEMENT_NAMES = new String[] { 
    ELEMENT_NAME_SIMPLETABLE, 
    ELEMENT_NAME_CHOICETABLE, 
    ELEMENT_NAME_PROPERTIES};
  
  /**
   * @see ro.sync.ecss.extensions.commons.AbstractDocumentTypeHelper#getTableCellElementNames()
   */
  @Override
  public String[] getTableCellElementNames() {
    return CELL_ELEMENT_NAMES;
  }

  /**
   * @see ro.sync.ecss.extensions.commons.AbstractDocumentTypeHelper#getTableRowElementNames()
   */
  @Override
  public String[] getTableRowElementNames() {
    return ROW_ELEMENT_NAMES;
  }

  /**
   * @see ro.sync.ecss.extensions.commons.AbstractDocumentTypeHelper#getTableElementLocalName()
   */
  @Override
  public String[] getTableElementLocalName() {
    return TABLE_ELEMENT_NAMES;
  }

  /**
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#checkTableColSpanIsDefined(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.AuthorTableCellSpanProvider, ro.sync.ecss.extensions.api.node.AuthorElement)
   */
  public void checkTableColSpanIsDefined(
      AuthorAccess authorAccess, 
      AuthorTableCellSpanProvider tableSpanSupport, 
      AuthorElement cellElement) throws AuthorOperationException {
    // Not implemented
  }

  /**
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#updateTableColSpan(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.AuthorTableCellSpanProvider, ro.sync.ecss.extensions.api.node.AuthorElement, int, int)
   */
  public void updateTableColSpan(
      AuthorAccess authorAccess,
      AuthorTableCellSpanProvider tableSupport,
      AuthorElement cellElem,
      int startCol,
      int endCol) throws AuthorOperationException {
    // Not implemented
  }

  /**
   * Creates a {@link SimpleTableCellSpanProvider} over the table element.
   * 
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#getTableCellSpanProvider(ro.sync.ecss.extensions.api.node.AuthorElement)
   */
  public AuthorTableCellSpanProvider getTableCellSpanProvider(AuthorElement tgroupElement) {
    SimpleTableCellSpanProvider tableSpanSupport = 
      new SimpleTableCellSpanProvider();
    tableSpanSupport.init(tgroupElement);    
    return tableSpanSupport;
  }

  /**
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#updateTableRowSpan(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.node.AuthorElement, int)
   */
  public void updateTableRowSpan(AuthorAccess authorAccess, AuthorElement cellElem, int rowSpan) {
    // Not implemented
  }

  /**
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#updateTableColumnNumber(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.node.AuthorElement, int)
   */
  public void updateTableColumnNumber(
      AuthorAccess authorAccess, 
      AuthorElement tableElement, 
      int colsNumber) {
    // Not applicable
  }

  /**
   * @see ro.sync.ecss.extensions.commons.table.operations.AuthorTableHelper#updateTableRowNumber(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.node.AuthorElement, int)
   */
  public void updateTableRowNumber(AuthorAccess authorAccess, AuthorElement tableElement,
      int rowsNumber) {
    // Nothing to do here.
  }
}