/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package simple.documentation.framework.extensions;

import java.net.URL;
import java.util.List;

import ro.sync.ecss.extensions.api.AuthorAccess;
import ro.sync.ecss.extensions.api.AuthorExternalObjectInsertionHandler;
import ro.sync.ecss.extensions.api.AuthorOperationException;
import ro.sync.ecss.extensions.api.node.AuthorDocumentFragment;
import ro.sync.util.URLUtil;

/**
 * Accepts insertion of images and XML files from external sources.
 */
public class SDFExternalObjectInsertionHandler extends AuthorExternalObjectInsertionHandler {
  /**
   * @see ro.sync.ecss.extensions.api.AuthorExternalObjectInsertionHandler#insertURLs(ro.sync.ecss.extensions.api.AuthorAccess, java.util.List, int)
   */
  @Override
  public void insertURLs(AuthorAccess authorAccess, List<URL> urls, int source)
      throws AuthorOperationException {
    for (URL url : urls) {
      String xmlFragment = null;
      if (authorAccess.getUtilAccess().isSupportedImageURL(url)) {
        // Insert an image element
         xmlFragment = "<image href=\"" + url.toString() + "\"/>";
      } else {
        // Insert 
        xmlFragment = "<ref location=\"" + url.toString() + "\"/>";
      }
      if (xmlFragment != null) {
        // Create am image fragment
        AuthorDocumentFragment imageFragment = authorAccess.getDocumentController().createNewDocumentFragmentInContext(
            xmlFragment, authorAccess.getEditorAccess().getCaretOffset());
        // Insert the fragment
        authorAccess.getDocumentController().insertFragment(authorAccess.getEditorAccess().getCaretOffset(), imageFragment);
      }
    }
  }
  
  /**
   * @see ro.sync.ecss.extensions.api.AuthorExternalObjectInsertionHandler#acceptSource(ro.sync.ecss.extensions.api.AuthorAccess, int)
   */
  @Override
  public boolean acceptSource(AuthorAccess authorAccess, int source) {
    if (source == DND_EXTERNAL) {
      // Accept only from external source
      return true;
    }
    // For urls from other sources (Dita Maps Manager, Project) a new tab will be open.
    return false;
  }
  
  /**
   * @see ro.sync.ecss.extensions.api.AuthorExternalObjectInsertionHandler#acceptURLs(ro.sync.ecss.extensions.api.AuthorAccess, java.util.List, int)
   */
  @Override
  public boolean acceptURLs(AuthorAccess authorAccess, List<URL> urls, int source) {
    boolean accept = acceptSource(authorAccess, source);
    if (accept) {
      for (int i = 0; i < urls.size(); i++) {
        // Accept only XML and image files
        if (!authorAccess.getUtilAccess().isSupportedImageURL(urls.get(i)) &&
            !"xml".equalsIgnoreCase(URLUtil.getExtension(urls.get(i).toString()))) {
          accept = false;
          break;
        }
      }
    } 
    return accept;
  }
}
