/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2011 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.ecss.extensions.api.content;

import ro.sync.annotations.api.API;
import ro.sync.annotations.api.APIType;
import ro.sync.annotations.api.SourceType;

/**
 * Current Text Context where the text content iterator is positioned.
 * 
 * @since 13
 * <br>
 * <br>
 * *********************************
 * <br>
 * EXPERIMENTAL - Subject to change
 * <br>
 * ********************************
 * </br>
 * <p>Please note that this API is not marked as final and it can change in one of the next versions of the application. If you have suggestions, 
 * comments about it, please let us know.</p>
 */
@API(type=APIType.NOT_EXTENDABLE, src=SourceType.PUBLIC)
public interface TextContext {
  /**
   * The returned text is in editable context.
   */
  int EDITABLE = 0;
  
  /**
   * The returned text is in editable context but a profiling condition is applied and filters the 
   * node when the output will be published..
   */
  int EDITABLE_IN_FILTERED_CONDITIONAL_PROFILING = 1;
  
  /**
   * The returned text is in delete change tracking context.
   */
  int NOT_EDITABLE_IN_DELETE_CHANGE_TRACKING = 2;
  
  /**
   * The returned text is in an entity or content reference.
   */
  int NOT_EDITABLE_IN_READ_ONLY = 3;

  /**
   * Gets the current text from the context.
   * 
   * @return The current text from the context.
   */
  CharSequence getText();
  
  /**
   * Gets the start offset of the returned text. The start offset is absolute in the Author Document's content.
   * 
   * @return The start offset of the returned text.
   */
  int getTextStartOffset();
  
  /**
   * Check if we can edit at the current iterator offset.
   * 
   * @return <code>true</code> if we can edit at the current iterator offset or <code>false</code>
   *        if we are in read-only content (entities, content references or delete change tracking).
   */
  int getEditableState();
  
  /**
   * Replaces the current context text with the new text content.
   * 
   * @param newTextContent The new text content.
   */
  void replaceText(CharSequence newTextContent);
}