/*
 *  The Syncro Soft SRL License
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  3. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  4. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  5. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  6. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.exml.workspace.api.standalone;

import java.net.URL;

import ro.sync.annotations.api.API;
import ro.sync.annotations.api.APIType;
import ro.sync.annotations.api.SourceType;

/**
 * Interface through which the CMS can set a custom URL to any Input URL Panel from Oxygen.
 * 
 * @since 12.1
 */
@API(type=APIType.NOT_EXTENDABLE, src=SourceType.PUBLIC)
public interface InputURLChooser {
  /**
   * Save resource chooser
   */
  public static final int SAVE_RESOURCE = 0;

  /**
   * Open resource chooser
   */
  public static final int OPEN_RESOURCE = 1;
  
  /**
   * Resource directory chooser
   */
  public static final int OPEN_RESOURCE_DIRECTORY = 2;

  /**
   * Set in the Input URL panel combo box the new URL which was chosen from the CMS handler.
   * When the customizer is used in places where a combo box for the URL is not present 
   * (like in the DITA Maps Manager view) this method performs the operation on the given URL.  
   * 
   * @param selectedURL The URL which was probably selected by the user in a custom CMS chooser. 
   */
  void urlChosen(URL selectedURL);
  
  /**
   * Get the mode for which the Input URL chooser will be used (for opening or for saving resources).
   * 
   * @return One of the constants in this class:
   *         {@link #OPEN_RESOURCE}, {@link #SAVE_RESOURCE} or {@link #OPEN_RESOURCE_DIRECTORY}
   * 
   * @since 12.2
   */
  int getBrowseMode();
  
  /**
   * Get the list of resource filters used for the local file chooser.
   * This method is useful to decide the type of files the chooser dialog wants to browse.
   * 
   * For example if the dialog wants to select an image to add to the Author page then the resource filters will contain image extensions. 
   * 
   * @return The list of resource filters used for the local file chooser. Can be <code>null</code>.
   * 
   * @since 13.1
   * <br>
   * <br>
   * *********************************
   * <br>
   * EXPERIMENTAL - Subject to change
   * <br>
   * ********************************
   * </br>
   * <p>Please note that this API is not marked as final and it can change in one of the next versions of the application. If you have suggestions, 
   * comments about it, please let us know.</p>
   */
  ResourceFilter[] getResourceFilters();
}